@@ -11,10 +11,10 @@
 //! };
 //! 
 //! fn main() -> Result<(), EkkoError> {
-//!     let mut sender = Ekko::with_target(([8, 8, 8, 8], 0))?;
+//!     let sender = Ekko::with_target([8, 8, 8, 8])?;
 //! 
-//!     for hops in 0..64 {
-//!         let responses = sender.send_range(0..(hops))?;
+//!     for hops in 0..32 {
+//!         let responses = sender.send_range(0..hops)?;
 //!         for ekko in responses.iter() {
 //!             match ekko {
 //! 
@@ -26,7 +26,7 @@
 //!                     return Ok(()) 
 //!                 }
 //! 
-//!                 _ => continue
+//!                 ekko => continue
 //!             }
 //!         }
 //!     }
@@ -48,10 +48,6 @@ pub use responses::{
     UnreachableCodeV4,
     Unreachable,
 
-    ParameterProblemV6,
-    ParameterProblemV4,
-    ParameterProblem,
-
     Redirect,
 
     EkkoResponse,
